@@ -7,14 +7,14 @@ mkdir -p "$(dirname "$CUSTOM_LOG_BASENAME.log")" && touch "$CUSTOM_LOG_BASENAME.
 
 CONFIG_CONTENTS=$(< "$CUSTOM_CONFIG_FILENAME")
 
-# Function to append miner name to workername (using underscore)
 set_worker_name() {
     local config="$1"
     local miner_name="$2"
 
-    echo "$config" | sed -E \
-        -e "s/(--user[[:space:]]+hoosat:[0-9a-fA-F]{64})\.([^[:space:]]+)/\1.\2_${miner_name}/" \
-        -e "s/(--user[[:space:]]+hoosat:[0-9a-fA-F]{64})([[:space:]]|$)/\1.${miner_name}\2/"
+    # Critical fix: printf emits real newlines → sed sees lines
+    printf '%s\n' "$config" | sed -E \
+        -e "s/(--user[[:space:]]+hoosat:[0-9a-fA-F]{61}\.)([^[:space:]]+)/\1\2_${miner_name}/g" \
+        -e "s/(--user[[:space:]]+hoosat:[0-9a-fA-F]{61})([[:space:]]|$)/\1.${miner_name}\2/g"
 }
 
 # --- Run miners in parallel ---
